@@ -234,8 +234,7 @@ pub fn solve(
         (2019, 14, 2) => to_stringer(year2019::day14::part2, input_string),
         (2019, 15, 1) => to_stringer(year2019::day15::part1, input_string),
         (2019, 15, 2) => to_stringer(year2019::day15::part2, input_string),
-        (2019, 16, 1) => to_stringer(year2019::day16::part1, input_string),
-        (2019, 16, 2) => to_stringer(year2019::day16::part2, input_string),
+        (2019, 16, _) => to_stringer_input(year2019::day16::solve, &mut input),
         (2019, 17, 1) => to_stringer(year2019::day17::part1, input_string),
         (2019, 17, 2) => to_stringer(year2019::day17::part2, input_string),
         (2019, 18, _) => to_stringer_input(year2019::day18::solve, &mut input),
